@@ -117,8 +117,10 @@ class K8sJobRunner(jobs.BaseJobRunner):
         # Define k8s entrypoint/args
         shell_command = ["sh", "-e", "-c"]
         if job["spec"]["template"]["spec"]["containers"][0].get("command") == []:
-            # Empty "command" (aka: entrypoint) might not be taken into account by jobs, so we need to manually
-            # override the entrypoint. We do not do this for every job, because some entrypoints are actually useful.
+            # In some cases, we need to bypass the container entrypoint.
+            # Unfortunately, AFAIK, there is no way to do so in K8s manifests. So we mark
+            # some jobs with "command: []". For these jobs, the entrypoint becomes "sh -e -c".
+            # We do not do this for every job, because some (most) entrypoints are actually useful.
             job["spec"]["template"]["spec"]["containers"][0]["command"] = shell_command
             container_args = [command]
         else:
@@ -478,7 +480,7 @@ def upgrade_from_koa(config: Config) -> None:
 your MongoDb cluster from v3.6 to v4.0. You should run something similar to:
 
     tutor k8s stop
-    tutor config save --set DOCKER_IMAGE_MONGODB=mongo:4.0
+    tutor config save --set DOCKER_IMAGE_MONGODB=mongo:4.0.25
     tutor k8s start
     tutor k8s exec mongodb mongo --eval 'db.adminCommand({ setFeatureCompatibilityVersion: "4.0" })'
     tutor config save --unset DOCKER_IMAGE_MONGODB
